@@ -27,7 +27,96 @@ except ImportError as e:
 
 
 class VisualizationSetConduit(rd.DisplayConduit):
-    """Class to preview VisualizationSet in the Rhino scene."""
+    """Class to preview VisualizationSet in the Rhino Display pipeline."""
+
+    def __init__(self, visualization_set, render_3d_legend=False):
+        """Initialize VisualizationSetConduit."""
+        # set the primary properties
+        self.vis_con = VisualizationSetConverter(visualization_set, render_3d_legend)
+
+    def CalculateBoundingBox(self, calculateBoundingBoxEventArgs):
+        """Overwrite the method that passes the bounding box to the display."""
+        calculateBoundingBoxEventArgs.IncludeBoundingBox(self.vis_con.bbox)
+
+    def PreDrawObjects(self, drawEventArgs):
+        """Overwrite the method that draws the objects in the display."""
+        # get the DisplayPipeline from the event arguments
+        display = drawEventArgs.Display
+
+        # for each object to be rendered, pass the drawing arguments
+        for draw_args in self.vis_con.draw_3d_text:
+            display.Draw3dText(*draw_args)
+        for draw_args in self.vis_con.draw_mesh_false_colors:
+            display.DrawMeshFalseColors(draw_args)
+        for draw_args in self.vis_con.draw_mesh_wires:
+            display.DrawMeshWires(*draw_args)
+        for draw_args in self.vis_con.draw_mesh_shaded:
+            display.DrawMeshShaded(*draw_args)
+        for draw_args in self.vis_con.draw_mesh_vertices:
+            display.DrawMeshVertices(*draw_args)
+        for draw_args in self.vis_con.draw_point:
+            display.DrawPoint(*draw_args)
+        for draw_args in self.vis_con.draw_arrow:
+            display.DrawArrow(*draw_args)
+        for draw_args in self.vis_con.draw_brep_shaded:
+            display.DrawBrepShaded(*draw_args)
+        for draw_args in self.vis_con.draw_brep_wires:
+            display.DrawBrepWires(*draw_args)
+        for draw_args in self.vis_con.draw_line:
+            display.DrawLine(*draw_args)
+        for draw_args in self.vis_con.draw_patterned_line:
+            display.DrawPatternedLine(*draw_args)
+        for draw_args in self.vis_con.draw_patterned_polyline:
+            display.DrawPatternedPolyline(*draw_args)
+        for draw_args in self.vis_con.draw_curve:
+            display.DrawCurve(*draw_args)
+        for draw_args in self.vis_con.draw_circle:
+            display.DrawCircle(*draw_args)
+        for draw_args in self.vis_con.draw_arc:
+            display.DrawArc(*draw_args)
+        for draw_args in self.vis_con.draw_sphere:
+            display.DrawSphere(*draw_args)
+        for draw_args in self.vis_con.draw_cone:
+            display.DrawCone(*draw_args)
+        for draw_args in self.vis_con.draw_cylinder:
+            display.DrawCylinder(*draw_args)
+
+
+class VisualizationSetConverter(object):
+    """Class to translate VisualizationSets to arguments for the Rhino display pipeline.
+
+    Args:
+        visualization_set: A Ladybug Display VisualizationSet object to be translated
+            into arguments for the Rhino display pipeline.
+        render_3d_legend: A Boolean to note whether the VisualizationSet should be
+            rendered with 3D legends for any AnalysisGeometries it
+            includes. (Default: False).
+
+    Properties:
+        * vis_set
+        * render_3d_legend
+        * min_pt
+        * max_pt
+        * bbox
+        * draw_3d_text
+        * draw_mesh_false_colors
+        * draw_mesh_shaded
+        * draw_mesh_wires
+        * draw_mesh_vertices
+        * draw_brep_shaded
+        * draw_brep_wires
+        * draw_point
+        * draw_arrow
+        * draw_line
+        * draw_patterned_line
+        * draw_patterned_polyline
+        * draw_curve
+        * draw_circle
+        * draw_arc
+        * draw_sphere
+        * draw_cone
+        * draw_cylinder
+    """
     TEXT_HORIZ = {
         'Left': ro.TextHorizontalAlignment.Left,
         'Center': ro.TextHorizontalAlignment.Center,
@@ -45,7 +134,7 @@ class VisualizationSetConduit(rd.DisplayConduit):
     }
 
     def __init__(self, visualization_set, render_3d_legend=False):
-        """Initialize VisualizationSetConduit."""
+        """Initialize VisualizationSetConverter."""
         # set the primary properties
         self.vis_set = visualization_set
         self.render_3d_legend = render_3d_legend
@@ -67,53 +156,7 @@ class VisualizationSetConduit(rd.DisplayConduit):
 
         # translate all of the rhino objects to be rendered in the scene
         self.translate_objects()
-
-    def CalculateBoundingBox(self, calculateBoundingBoxEventArgs):
-        """Overwrite the method that passes the bounding box to the display."""
-        calculateBoundingBoxEventArgs.IncludeBoundingBox(self.bbox)
-
-    def PreDrawObjects(self, drawEventArgs):
-        """Overwrite the method that draws the objects in the display."""
-        # get the DisplayPipeline from the event arguments
-        display = drawEventArgs.Display
-
-        # for each object to be rendered, pass the drawing arguments
-        for draw_args in self.draw_3d_text:
-            display.Draw3dText(*draw_args)
-        for draw_args in self.draw_mesh_false_colors:
-            display.DrawMeshFalseColors(draw_args)
-        for draw_args in self.draw_mesh_wires:
-            display.DrawMeshWires(*draw_args)
-        for draw_args in self.draw_mesh_shaded:
-            display.DrawMeshShaded(*draw_args)
-        for draw_args in self.draw_mesh_vertices:
-            display.DrawMeshVertices(*draw_args)
-        for draw_args in self.draw_point:
-            display.DrawPoint(*draw_args)
-        for draw_args in self.draw_arrow:
-            display.DrawArrow(*draw_args)
-        for draw_args in self.draw_brep_shaded:
-            display.DrawBrepShaded(*draw_args)
-        for draw_args in self.draw_brep_wires:
-            display.DrawBrepWires(*draw_args)
-        for draw_args in self.draw_line:
-            display.DrawLine(*draw_args)
-        for draw_args in self.draw_patterned_line:
-            display.DrawPatternedLine(*draw_args)
-        for draw_args in self.draw_patterned_polyline:
-            display.DrawPatternedPolyline(*draw_args)
-        for draw_args in self.draw_curve:
-            display.DrawCurve(*draw_args)
-        for draw_args in self.draw_circle:
-            display.DrawCircle(*draw_args)
-        for draw_args in self.draw_arc:
-            display.DrawArc(*draw_args)
-        for draw_args in self.draw_sphere:
-            display.DrawSphere(*draw_args)
-        for draw_args in self.draw_cone:
-            display.DrawCone(*draw_args)
-        for draw_args in self.draw_cylinder:
-            display.DrawCylinder(*draw_args)
+        self.sort_shaded_objects()
 
     def translate_objects(self):
         """Translate all of the objects in the VisualizationSet into a Rhino equivalent.
@@ -302,11 +345,11 @@ class VisualizationSetConduit(rd.DisplayConduit):
                     else from_polyface3d(geo_obj)
                 self.draw_brep_shaded.append((rh_obj, mat))
                 if display_mode == 'SurfaceWithEdges':
-                    self.draw_brep_wires.append((rh_obj, black(), 1))
+                    self.draw_brep_wires.append((rh_obj, black(), -1))
             elif display_mode == 'Wireframe':
                 rh_obj = from_face3d(geo_obj) if isinstance(geo_obj, Face3D) \
                     else from_polyface3d(geo_obj)
-                self.draw_brep_wires.append((rh_obj, col, 3))
+                self.draw_brep_wires.append((rh_obj, col, 1))
             elif display_mode == 'Points':
                 for pt in geo_obj.vertices:
                     self.draw_point.append(
@@ -426,7 +469,7 @@ class VisualizationSetConduit(rd.DisplayConduit):
             # translate display point
             pt = from_point3d(geo_obj) if isinstance(geo_obj, Point3D) \
                 else from_point2d(geo_obj)
-            radius = 3 if isinstance(dis_obj.radius, Default) else dis_obj.radius
+            radius = 3 if isinstance(dis_obj.radius, Default) else int(dis_obj.radius)
             self.draw_point.append((pt, rd.PointStyle.RoundSimple, radius, col))
 
         elif isinstance(geo_obj, (LineSegment3D, LineSegment2D)):
@@ -466,7 +509,7 @@ class VisualizationSetConduit(rd.DisplayConduit):
                     else from_polyface3d(geo_obj)
                 self.draw_brep_shaded.append((rh_obj, mat))
                 if dis_obj.display_mode == 'SurfaceWithEdges':
-                    self.draw_brep_wires.append((rh_obj, black(), 1))
+                    self.draw_brep_wires.append((rh_obj, black(), -1))
             elif dis_obj.display_mode == 'Wireframe':
                 rh_obj = from_face3d(geo_obj) if isinstance(geo_obj, Face3D) \
                     else from_polyface3d(geo_obj)
@@ -588,3 +631,18 @@ class VisualizationSetConduit(rd.DisplayConduit):
             if dis_obj.show_axes:
                 self.draw_line.append((pln.Origin, pln.Origin + pln.XAxis * r, col, 3))
                 self.draw_line.append((pln.Origin, pln.Origin + pln.YAxis * r, col, 3))
+
+    def sort_shaded_objects(self):
+        """Sort shaded objects according to their transparency.
+
+        This ensures that the resulting display has visible objects behind
+        any transparent objects.
+        """
+        if len(self.draw_brep_shaded) != 0:
+            trans = (args[1].Transparency for args in self.draw_brep_shaded)
+            self.draw_brep_shaded = \
+                [a for _, a in sorted(zip(trans, self.draw_brep_shaded))]
+        if len(self.draw_mesh_shaded) != 0:
+            trans = (args[1].Transparency for args in self.draw_mesh_shaded)
+            self.draw_mesh_shaded = \
+                [a for _, a in sorted(zip(trans, self.draw_mesh_shaded))]
