@@ -18,7 +18,7 @@ try:
     import Grasshopper as gh
 except ImportError:
     print('Failed to import Grasshopper.\n'
-          'Only functions for adding text to Rhino will be availabe.')
+          'Only functions for adding text to Rhino will be available.')
 
 
 def text_objects(text, plane, height, font='Arial',
